#!/bin/sh
# SPDX-License-Identifier: BSD-2-Clause
# SPDX-FileCopyrightText: © 2016 Antoine Le Gonidec <vv221@dotslashplay.it>
set -o errexit

###
# Ghost Master
###

script_version=20230920.1

PLAYIT_COMPATIBILITY_LEVEL='2.26'

GAME_ID='ghost-master'
GAME_NAME='Ghost Master'

ARCHIVE_BASE_1_NAME='setup_ghost_master_20171020_(15806).exe'
ARCHIVE_BASE_1_MD5='bbc7b8d6ed9b08c54cba6f2b1048a0fd'
ARCHIVE_BASE_1_TYPE='innosetup'
ARCHIVE_BASE_1_SIZE='680000'
ARCHIVE_BASE_1_VERSION='1.1-gog15806'
ARCHIVE_BASE_1_URL='https://www.gog.com/game/ghost_master'

ARCHIVE_BASE_0_NAME='setup_ghost_master_2.0.0.3.exe'
ARCHIVE_BASE_0_MD5='f581e0e08d7d9dfc89838c3ac892611a'
ARCHIVE_BASE_0_TYPE='innosetup'
ARCHIVE_BASE_0_SIZE='650000'
ARCHIVE_BASE_0_VERSION='1.1-gog2.0.0.3'

CONTENT_PATH_DEFAULT='app/ghostdata'
CONTENT_GAME_BIN_FILES='
*.cfg
*.dll
*.exe'
CONTENT_GAME_DATA_FILES='
characters
cursors
fonts
icons
levels
movies
music
new_animations
otherobjects
psparams
pstextures
scenarios
screenshots
scripts
sound
text
ui
voice
*.txt'
CONTENT_DOC_DATA_PATH="${CONTENT_PATH_DEFAULT}/.."
CONTENT_DOC_DATA_FILES='
*.pdf
*.txt'

WINE_PERSISTENT_DIRECTORIES='
users/Public/Documents/Ghost Master/SaveGames'

USER_PERSISTENT_DIRECTORIES='
screenshots'
USER_PERSISTENT_FILES='
*.cfg'

APP_MAIN_EXE='ghost.exe'

PACKAGES_LIST='PKG_BIN PKG_DATA'

PKG_DATA_ID="${GAME_ID}-data"
PKG_DATA_DESCRIPTION='data'

PKG_BIN_ARCH='32'
PKG_BIN_DEPS="$PKG_DATA_ID"
PKG_BIN_DEPENDENCIES_GSTREAMER_PLUGINS='
deinterlace
video/x-ms-asf
audio/x-wma, wmaversion=(int)1
video/x-wmv, wmvversion=(int)1'

# Load common functions

PLAYIT_LIB_PATHS="
$PWD
${XDG_DATA_HOME:="${HOME}/.local/share"}/play.it
/usr/local/share/games/play.it
/usr/local/share/play.it
/usr/share/games/play.it
/usr/share/play.it"

if [ -z "$PLAYIT_LIB2" ]; then
	for playit_lib_path in $PLAYIT_LIB_PATHS; do
		if [ -e "${playit_lib_path}/libplayit2.sh" ]; then
			PLAYIT_LIB2="${playit_lib_path}/libplayit2.sh"
			break
		fi
	done
fi
if [ -z "$PLAYIT_LIB2" ]; then
	printf '\n\033[1;31mError:\033[0m\n'
	printf 'libplayit2.sh not found.\n'
	exit 1
fi
. "$PLAYIT_LIB2"

# Extract game data

archive_extraction_default

# Include game icons

PKG='PKG_DATA'
icons_inclusion

# Include game data

content_inclusion_default

# Write launchers

PKG='PKG_BIN'
launchers_write

# Build packages

packages_generation

# Print instructions

print_instructions

# Clean up

rm --recursive "$PLAYIT_WORKDIR"

exit 0
