#!/bin/sh
# SPDX-License-Identifier: BSD-2-Clause
# SPDX-FileCopyrightText: © 2023 Antoine Le Gonidec <vv221@dotslashplay.it>
set -o errexit

###
# Grim Dawn
###

script_version=20231211.1

PLAYIT_COMPATIBILITY_LEVEL='2.27'

GAME_ID='grim-dawn'
GAME_NAME='Grim Dawn'

ARCHIVE_BASE_3_NAME='setup_grim_dawn_1.2.0.3_hotfix_3_(64bit)_(69499).exe'
ARCHIVE_BASE_3_MD5='d407d7f0c13b2e9a09c9d507a6dd9406'
ARCHIVE_BASE_3_TYPE='innosetup'
ARCHIVE_BASE_3_PART1_NAME='setup_grim_dawn_1.2.0.3_hotfix_3_(64bit)_(69499)-1.bin'
ARCHIVE_BASE_3_PART1_MD5='cb0b21ec562a0023650928cabd3f2aac'
ARCHIVE_BASE_3_SIZE='4716376'
ARCHIVE_BASE_3_VERSION='1.2.0.3-gog69499'
ARCHIVE_BASE_3_URL='https://www.gog.com/game/grim_dawn'

ARCHIVE_BASE_2_NAME='setup_grim_dawn_1.2.0.2_hotfix_2_(64bit)_(69134).exe'
ARCHIVE_BASE_2_MD5='a86614183a27085a644642e73c89dc31'
ARCHIVE_BASE_2_TYPE='innosetup'
ARCHIVE_BASE_2_PART1_NAME='setup_grim_dawn_1.2.0.2_hotfix_2_(64bit)_(69134)-1.bin'
ARCHIVE_BASE_2_PART1_MD5='d4088f8591111a2aa1c5af081179ec38'
ARCHIVE_BASE_2_SIZE='4414600'
ARCHIVE_BASE_2_VERSION='1.2.0.2-gog69134'

ARCHIVE_BASE_1_NAME='setup_grim_dawn_1.2.0.1_hotfix_1_(64bit)_(69098).exe'
ARCHIVE_BASE_1_MD5='0b4edacfee791cc6d83af7a2c36cb11c'
ARCHIVE_BASE_1_TYPE='innosetup'
ARCHIVE_BASE_1_PART1_NAME='setup_grim_dawn_1.2.0.1_hotfix_1_(64bit)_(69098)-1.bin'
ARCHIVE_BASE_1_PART1_MD5='9450bc1b82d609709356e7b3bb76570f'
ARCHIVE_BASE_1_SIZE='4411128'
ARCHIVE_BASE_1_VERSION='1.2.0.1-gog69098'

ARCHIVE_BASE_0_NAME='setup_grim_dawn_1.1.9.8_(64bit)_(65199).exe'
ARCHIVE_BASE_0_MD5='c0fb173132b21833052d1496f6ab832e'
ARCHIVE_BASE_0_TYPE='innosetup'
ARCHIVE_BASE_0_PART1_NAME='setup_grim_dawn_1.1.9.8_(64bit)_(65199)-1.bin'
ARCHIVE_BASE_0_PART1_MD5='d97de2b8cd7ae7aa723e720ec2fa21f5'
ARCHIVE_BASE_0_SIZE='4332472'
ARCHIVE_BASE_0_VERSION='1.1.9.8-gog65199'

CONTENT_PATH_DEFAULT='.'
CONTENT_GAME_BIN_FILES='
x64
*.dll
*.dlo
*.exe'
CONTENT_GAME_DATA_FILES='
database
resources
video
*.zip
minimap.atn'
CONTENT_DOC_DATA_FILES='
grim dawn modding guide.pdf'

WINE_DIRECT3D_RENDERER='dxvk'
WINE_PERSISTENT_DIRECTORIES='
users/${USER}/Documents/My Games/Grim Dawn'

APP_MAIN_EXE='x64/grim dawn.exe'

PACKAGES_LIST='
PKG_BIN
PKG_DATA'

PKG_DATA_ID="${GAME_ID}-data"
PKG_DATA_DESCRIPTION='data'

PKG_BIN_ARCH='64'
PKG_BIN_DEPS="$PKG_DATA_ID"

# Load common functions

PLAYIT_LIB_PATHS="
$PWD
${XDG_DATA_HOME:="${HOME}/.local/share"}/play.it
/usr/local/share/games/play.it
/usr/local/share/play.it
/usr/share/games/play.it
/usr/share/play.it"

if [ -z "$PLAYIT_LIB2" ]; then
	for playit_lib_path in $PLAYIT_LIB_PATHS; do
		if [ -e "${playit_lib_path}/libplayit2.sh" ]; then
			PLAYIT_LIB2="${playit_lib_path}/libplayit2.sh"
			break
		fi
	done
fi
if [ -z "$PLAYIT_LIB2" ]; then
	printf '\n\033[1;31mError:\033[0m\n'
	printf 'libplayit2.sh not found.\n'
	exit 1
fi
. "$PLAYIT_LIB2"

# Extract game data

archive_extraction_default
(
	cd "${PLAYIT_WORKDIR}/gamedata/$(content_path_default)"

	## Delete unwanted files.
	rm --recursive \
		'__redist' \
		'app' \
		'commonappdata' \
		'tmp'
)

# Include game data

set_current_package 'PKG_DATA'
icons_inclusion
content_inclusion_default

# Write launchers

set_current_package 'PKG_BIN'
launchers_write

# Build packages

packages_generation
print_instructions

# Clean up

rm --recursive "$PLAYIT_WORKDIR"

exit 0
